# Original License
In order that the comments on each source file don't stretch into the hundreds, while still maintaining credit and provenance to the original project, the original BrewPi project license statement follows (taken from the header of the source files.)  If a file has been modified in any way for the BrewPi Remix project, the license comments on the code header have been changed to that of the new (derivative) project.  Any new files will use the new license comments.

> Copyright 2012 BrewPi/Elco Jacobs. This file is part of BrewPi.
> 
> BrewPi is free software: you can redistribute it and/or modify it 
> under the terms of the GNU General Public License as published by the 
> Free Software Foundation, either version 3 of the License, or (at your 
> option) any later version.
> 
> BrewPi is distributed in the hope that it will be useful, but WITHOUT 
> ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or 
> FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License 
> for more details.
> 
> You should have received a copy of the GNU General Public License 
> along with BrewPi.  If not, see <http://www.gnu.org/licenses/.
